@@ -78,7 +78,8 @@
 # error
 #endif
 
-#if ( defined __unix__ && !defined __CYGWIN__ ) || defined _AIX
+#if ( defined __unix__ && !defined __CYGWIN__ ) || defined _AIX \
+    || defined __vxworks
 # if !#system(unix)
 #  error
 # endif
@@ -208,7 +209,7 @@
 # error
 #endif
 
-#if defined __h8300__ 
+#if defined __H8300__ 
 # if !#cpu(h8300) || !#machine(h8300) \
   || (defined __H8300__ && (!#cpu(h8300) || !#machine(h8300))) \
   || (defined __H8300H__ && (!#cpu(h8300h) || !#machine(h8300h))) \
@@ -254,14 +255,6 @@
 # error
 #endif
 
-#if defined __i860__
-# if !#cpu(i860) || !#machine(i860)
-#  error
-# endif
-#elif #cpu(i860) || #machine(i860)
-# error
-#endif
-
 #if defined __ia64__
 # if !#cpu(ia64) || !#machine(ia64)
 #  error
@@ -319,14 +312,6 @@
 # error
 #endif
 
-#if defined __ns32k__
-# if !#cpu(ns32k) || !#machine(ns32k)
-#  error
-# endif
-#elif #cpu(ns32k) || #machine(ns32k)
-# error
-#endif
-
 #if defined __pdp11__
 # if !#cpu(pdp11) || !#machine(pdp11)
 #  error
