@@ -6,6 +6,8 @@
       PROGRAM FM413
       IMPLICIT LOGICAL (L)
       IMPLICIT CHARACTER*14 (C)
+      IMPLICIT INTEGER(4) (I)
+      DATA IPROG, IFILE, ITOTR, IRLGN, IRECN, IEOF,ICON21, ICON22, ICON31, ICON32, ICON33, ICON34, ICON55, ICON56 /14*0/
       OPEN (7, ACCESS = 'DIRECT', RECL = 80, STATUS='REPLACE', FILE="FOO" )
       IRECN = 13
       IREC = 13
